<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>व्यंजक त्रुटि</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>सरल मोड</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>विज्ञान मोड</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>व्यंजक त्रुटि</translation>
    </message>
</context>
</TS>